/*
******************************************************************************

   OVL implementation for X target - initialization.

   Display-X: initialization

   Copyright (C) 2001	Christoph Egger	[Christoph_Egger@t-online.de]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "xovl.h"


static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
		   const char *args, void *argptr, uint32 *dlret)
{
	OVLDPRINT_LIBS("GGIopen(%p, %p, %s, %p, %p) called for X_ovl sublib\n",
		vis, dlh, args ? args : "(NULL)", argptr, dlret);


	XOVL_PRIV(vis) = NULL;
#if 0
	XOVL_PRIV(vis) = malloc(sizeof(struct xovl_priv));
	if (XOVL_PRIV(vis) == NULL) return GGI_ENOMEM;
#endif
	LIBGGI_OVLEXT(vis)->tie = OVL_X_tie;

	LIBGGI_OVLEXT(vis)->setimage = OVL_X_setimage;

	LIBGGI_OVLEXT(vis)->setpos = OVL_X_setpos;
	LIBGGI_OVLEXT(vis)->move = OVL_X_move;

	LIBGGI_OVLEXT(vis)->setsize = OVL_X_setsize;
	LIBGGI_OVLEXT(vis)->setpriority = OVL_X_setpriority;
	LIBGGI_OVLEXT(vis)->setflags = OVL_X_setflags;

	LIBGGI_OVLEXT(vis)->setzoom = OVL_X_setzoom;

	LIBGGI_OVLEXT(vis)->show = OVL_X_show;
	LIBGGI_OVLEXT(vis)->hide = OVL_X_hide;

	LIBGGI_OVLEXT(vis)->enable = OVL_X_enable;
	LIBGGI_OVLEXT(vis)->disable = OVL_X_disable;


	*dlret = (GGI_DL_EXTENSION | GGI_DL_OPDISPLAY);
	return 0;
}	/* GGIopen */


static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
{
	OVLDPRINT_LIBS("GGIclose(%p, %p) called for X_ovl sublib\n",
	       vis, dlh);

#if 0
	free(XOVL_PRIV(vis));
	XOVL_PRIV(vis) = NULL;
#endif

	return 0;
}	/* GGIclose */


int OVLdl_X_ovl(int func, void **funcptr)
{
	switch (func) {
	case GGIFUNC_open:
		*funcptr = GGIopen;
		return 0;
	case GGIFUNC_exit:
		*funcptr = NULL;
		return 0;
	case GGIFUNC_close:
		*funcptr = GGIclose;
		return 0;
	default:
		*funcptr = NULL;
	}	/* switch */

	return GGI_ENOTFOUND;
}	/* OVLdl_X_ovl */

/* This should be included by exactly _one_ file in each sublib. */
#include <ggi/internal/ggidlinit.h>
